local L = LibStub("AceLocale-3.0"):GetLocale("Titan", true)
local LB = LibStub("AceLocale-3.0"):GetLocale("TitanPals", true)
local AceConfigDialog = LibStub("AceConfigDialog-3.0")
local AceConfig = LibStub("AceConfig-3.0")
local Dewdrop = nil
if AceLibrary:HasInstance("Dewdrop-2.0") then Dewdrop = AceLibrary("Dewdrop-2.0") end

-- ******************************** Config Panel *******************************

-- ******************************** Data Arrays *******************************
palsDB = nil;
authors = {
     "Nagdand@Laughing Skull",
     "Havikil@Laughing Skull",
     "Lindarena@Laughing Skull",
     "Taintedjurky@Laughing Skull",
     "Mordrel@Laughing Skull",
     "Corelg@Laughing Skull",
     "Theli@Korialstrasz",
     "Tyria@Korialstrasz",
     "Riya@Korialstrasz",
     "Ryria@Korialstrasz",
     "Reline@Korialstrasz",
     "Nagdand@Korialstrasz",
     "Nagdand@Icecrown",
     "Berr@Icecrown",
     "Pameliya@Icecrown",
     "Dison@Sentiels",
     "Dorid@Sentiels",
     "Niris@Undermine",
     "AdiBeiBlizzard@Garrosh",
     "AdiBeiBlizzard@Area 52",
}

local presets = {
     { name = "Style #1          !s (!l !c) !p | !n !z", value = "!s (!l !c) !p | !n !z", },
     { name = "Style #2          !s (!l) !uc | !n !z", value = "!s (!l) !uc | !n !z", },
     { name = "Style #3          !s (!l) !p - !c !z | !n", value = "!s (!l) !p - !c !z | !n", },
     { name = "Style #4          !s (!l) !c - !p !z | !n", value = "!s (!l) !c - !p !z | !n", },
     { name = "Style #5          !s (!l) !uc !z | !n]", value = "!s (!l) !uc !z | !n", },
     { name = "Style #6          !s !p (!l) - !c !n | !z", value = "!s !p (!l) - !c !n | !z", },
     { name = "Style #7          !s !z (!l) - !c !n | !p", value = "!s !z (!l) - !c !n | !p", },
     { name = "Style #8          !s !c (!l) !z !n | !p", value = "!s !c (!l) !z !n | !p", },
}

-- Core ( enUS only non-translateable )
LB["TITAN_PALS_CORE_ID"] = "Pals";
LB["TITAN_PALS_CORE_VERSION"] = GetAddOnMetadata("TitanPals","Version");
LB["TITAN_PALS_CORE_DTAG"] = "<TitanPals Debug>";
LB["TITAN_PALS_CORE_ITAG"] = "<TitanPals Info>";
LB["TITAN_PALS_CORE_ADDVER"] = "r23";
LB["TITAN_PALS_CORE_DBVER"] = "v2";
LB["TITAN_PALS_CORE_ARTWORK"] = "Interface\\AddOns\\TitanPals\\Artwork\\TitanPals";

-- **************************************************************************
-- NAME : TitanPanelPals_ConfigUtils(a)
-- DESC : Pull information from .toc for config dialog
-- **************************************************************************
local function TitanPanelPals_ConfigUtils(a)
     if ( a == "GetAuthor" ) then
          return GetAddOnMetadata("TitanPals", "Author") or L["TITAN_NA"];
     elseif ( a == "GetCategory" ) then
          return GetAddOnMetadata("TitanPals", "X-Category") or L["TITAN_NA"];
     elseif ( a == "GetEmail" ) then
          return GetAddOnMetadata("TitanPals", "X-Email") or L["TITAN_NA"];
     elseif ( a == "GetWebsite" ) then
          return GetAddOnMetadata("TitanPals", "X-Website") or L["TITAN_NA"];
     elseif ( a == "GetVersion" ) then
          return tostring(GetAddOnMetadata("TitanPals", "Version")) or L["TITAN_NA"];
     end
end

-- **************************************************************************
-- NAME : optionsPals
-- DESC : this is the root of the config dialog
-- **************************************************************************
local optionsPals = {
     name = "Titan Panel Pals",
     type = "group",
     args = {
          confgendesc = {
               order = 1,
               type = "description",
               name = LB["TITAN_PALS_CONFIG_LABEL"],
               cmdHidden = true
          },
          confinfodesc = {
	       order = 2,
               name = LB["TITAN_PALS_CONFIG_ABOUT"],
               type = "group", inline = true,
               args = {
                    confversiondesc = {
                         order = 1,
                         type = "description",			
                         name = "|cffffd700".."Version"..": ".._G["GREEN_FONT_COLOR_CODE"]..TitanPanelPals_ConfigUtils("GetVersion"),
                         cmdHidden = true
                    },
                    confauthordesc = {
                         order = 2,
                         type = "description",
                         name = "|cffffd700".."Author"..": ".."|cffff8c00"..TitanPanelPals_ConfigUtils("GetAuthor"),
                         cmdHidden = true
                    },
                    confcatdesc = {
                         order = 3,
                         type = "description",
                         name = "|cffffd700".."Category"..": ".._G["HIGHLIGHT_FONT_COLOR_CODE"]..TitanPanelPals_ConfigUtils("GetCategory"),
                         cmdHidden = true
                    },
                    confemaildesc = {
                         order = 4,
                         type = "description",
                         name = "|cffffd700".."Email"..": ".._G["HIGHLIGHT_FONT_COLOR_CODE"]..TitanPanelPals_ConfigUtils("GetEmail"),
                         cmdHidden = true
                    },
                    confwebsitedesc = {
                         order = 5,
                         type = "description",
                         name = "|cffffd700".."Website"..": ".._G["HIGHLIGHT_FONT_COLOR_CODE"]..TitanPanelPals_ConfigUtils("GetWebsite"),
                         cmdHidden = true
                    },
               }
          },
          conftooltipdesc = {
	       order = 3,
               name = LB["TITAN_PALS_CONFIG_SET_HEADER"],
               type = "group", inline = true,
               args = {
	            tooltippresets = {
                         order = 1, type = "select", width = "full",
                         name = LB["TITAN_PALS_CONFIG_PRESETS"],
                         desc = LB["TITAN_PALS_CONFIG_PRESETS_DESC"],
                         get = function() return TitanPals["TFormat"]; end,
                         set = function(_, v) TitanPals["TFormat"] = v; end,
                         values = function()
                              local preList = {};
                              local v;
                              for _, v in pairs( presets ) do
                                   if ( v.value ~= TitanPals["TFormat"] ) then
                                        preList[v.value] = "|cff19ff19"..v.name.."|r"
                                   else
                                        preList[v.value] = "|cffffff9a"..v.name.."|r"
                                   end
                              end
                              table.sort(preList, function(a, b)
                                   return string.lower(persets[a].name) < string.lower(persets[b].name)
                              end)
                              return preList;
                         end
                    },
                    nulloption1 = {
                         order = 2,
                         type = "description",
                         name = LB["TITAN_PALS_CONFIG_PRESETS_PREVIEW"],
                         cmdHidden = true
                    },
		    --[[
                    nulloption1 = {
                         order = 3,
                         type = "description",
                         name = "   ",
                         cmdHidden = true
                    },
                    setcustomhdear = {
                         order = 4,
                         type = "header",
                         name = LB["TITAN_PALS_CONFIG_SET_CUSTOM_HEADER"],
                    },
	            tooltiprightside = {
                         name = LB["TITAN_PALS_CONFIG_RIGHT"],
                         desc = LB["TITAN_PALS_CONFIG_RIGHT2"],
                         order = 5, type = "input", width = "half",
                         get = function() return TitanPals["Right"]; end,
                         set = function(_, v) TitanPals["Right"] = v; end,
                    },
	            tooltipleftside = {
                         name = LB["TITAN_PALS_CONFIG_LEFT"],
                         desc = LB["TITAN_PALS_CONFIG_LEFT2"],
                         order = 6, type = "input", width = "half",
			 get = function() return TitanPals["Left"]; end,
			 set = function(_, v) TitanPals["Left"] = v; end,
		    },
		    tooltiphelp = {
                         name = LB["TITAN_PALS_CONFIG_HELP"],
			 desc = LB["TITAN_PALS_CONFIG_HELP_DESC"],
			 order = 7, type = "execute",
			 get = function() return; end,
			 set = function() return; end,
		    },
		    ]]--
               },
	  },
          conftooltipsetting = {
               order = 3,
	       name = LB["TITAN_PALS_CONFIG_SET_HEADER_2"];
	       type = "group", inline = true,
	       args = {
		    tooltipshowoffline = {
                         name = LB["TITAN_PALS_CONFIG_SHOWOFFLINE"],
                         desc = LB["TITAN_PALS_CONFIG_SHOWOFFLINE_DESC"],
                         order = 1, type = "toggle",
                         get = function() return TitanPals["ShowOffline"]; end,
                         set = function() TitanPanelPals_CoreUtils("Toggle", "ShowOffline"); end,
                    },
                    tooltipshowignored = {
                         name = LB["TITAN_PALS_CONFIG_SHOWIGNORED"],
                         desc = LB["TITAN_PALS_CONFIG_SHOWIGNORED_DESC"],
                         order = 2, type = "toggle",
                         get = function() return TitanPals["ShowIgnored"]; end,
                         set = function() TitanPanelPals_CoreUtils("Toggle", "ShowIgnored"); end,
                    },
--[[                    tooltipshowclass = {
                         name = LB["TITAN_PALS_CONFIG_SHOWCLASS"],
                         desc = LB["TITAN_PALS_CONFIG_SHOWCLASS_DESC"],
                         order = 3, type = "toggle",
                         get = function() return TitanPals["ShowClass"]; end,
                         set = function() TitanPanelPals_CoreUtils("Toggle", "ShowClass"); end,
                    },
                    tooltipshownote = {
                         name = LB["TITAN_PALS_CONFIG_SHOWNOTE"],
                         desc = LB["TITAN_PALS_CONFIG_SHOWNOTE_DESC"],
                         order = 4, type = "toggle",
                         get = function() return TitanPals["ShowNote"]; end,
                         set = function() TitanPanelPals_CoreUtils("Toggle", "ShowNote"); end,
                    }, ]]--
                    tooltipshowmem = {
                         name = LB["TITAN_PALS_CONFIG_SHOWMEM"],
                         desc = LB["TITAN_PALS_CONFIG_SHOWMEM_DESC"],
                         order = 5, type = "toggle",
                         get = function() return TitanPals["ShowMem"]; end,
                         set = function() TitanPanelPals_CoreUtils("Toggle", "ShowMem"); end,
                    },
                    tooltipbannor = {
                         name = LB["TITAN_PALS_CONFIG_BANNOR"],
                         desc = LB["TITAN_PALS_CONFIG_BANNOR_DESC"],
                         order = 6, type = "toggle",
                         get = function() return TitanPals["DisplayB"]; end,
                         set = function() TitanPanelPals_CoreUtils("Toggle", "DisplayB"); end,
                    },
                    tooltipnoalts = {
                         name = LB["TITAN_PALS_CONFIG_NOALTS"],
                         desc = LB["TITAN_PALS_CONFIG_NOALTS_DESC"],
                         order = 7, type = "toggle", width = "full",
                         get = function() return TitanPals["NoAlts"]; end,
                         set = function() TitanPanelPals_CoreUtils("Toggle", "NoAlts"); end,
                    },
               },
          },
--[[
          confeditdesc = {
	       order = 4,
               name = LB["TITAN_PALS_CONFIG_SET_HEADER_3"],
               type = "group", inline = true,
               args = {
                    friendsarray = {
                         order = 1,
                         type = "select",
                         name = "Friend",
                         desc = LB["TITAN_PALS_CONFIG_PALS_EDIT"],
                         get = function() return TitanPals["Selected"]; end,
                         set = function(_, v) TitanPals["Selected"] = v; end,
                         values = function() 
                              local selecta = {};
			      table.insert(selecta, "Please Select a Friend");
                              for n, v in pairs(TitanPals["Lists"][palsDB]) do
                                   --table.insert(TitanPals["Temp"], n..":"..v); -- For debuging
                                   local lv, cl, no = string.match(v, '(.*):(.*):(.*)')
				   local name = TitanPanelPals_ColorUtils("GetCClass", "color", cl, n);
                                   table.insert(selecta, name);
                              end
                             return selecta;
                         end,
		    },
               },
          },
	  --This block is only enabled when I am working on the plugin
          debuginfodesc = {
               order = 5,
               name = "Debuging",
               type = "group", inline = true,
               args = {
                    debugmode = {
                         name = LB["TITAN_PALS_CONFIG_DEBUG"],
                         desc = LB["TITAN_PALS_CONFIG_DEBUG_DESC"],
                         order = 1, type = "toggle", --width = "half",
                         get = function() return TitanPals["Debug"]; end,
                         set = function()
                              TitanPanelPals_CoreUtils("Toggle", "Debug");
                         end,
                    },
                    debugeventmode = {
                         name = LB["TITAN_PALS_CONFIG_DEBUGEVENT"],
                         desc = LB["TITAN_PALS_CONFIG_DEBUGEVENT_DESC"],
                         order = 2, type = "toggle", --width = "half",
                         get = function() return TitanPals["DebugEvent"]; end,
                         set = function()
                              TitanPanelPals_CoreUtils("Toggle", "DebugEvent");
                         end,
                    },
                    debuglogeventmode = {
                         name = LB["TITAN_PALS_CONFIG_DEBUGLOGEVENT"],
                         desc = LB["TITAN_PALS_CONFIG_DEBUGLOGEVENT_DESC"],
                         order = 3, type = "toggle", --width = "half",
                         get = function() return TitanPals["DebugLogEvent"]; end,
                         set = function()
                              TitanPanelPals_CoreUtils("Toggle", "DebugLogEvent");
                         end,
                    },
	       },
          },  ]]--
     },
}
-- **************************************************************************
-- NAME : TitanPanelPalsButton_OnLoad()
-- DESC : Registers the plugin upon it loading
-- **************************************************************************
function TitanPanelPalsButton_OnLoad(self)
     self.registry = {
          id = LB["TITAN_PALS_CORE_ID"],
          builtIn = false,
          version = TITAN_VERSION,
          menuText = LB["TITAN_PALS_MENU_TEXT"],
          buttonTextFunction = "TitanPanelPalsButton_GetButtonText";
	  tooltipTitle = LB["TITAN_PALS_TOOLTIP"],
          tooltipCustomFunction = TitanPanelPalsButton_SetTooltip;
          icon = LB["TITAN_PALS_CORE_ARTWORK"],
          iconWidth = 16,
          category = "Information",
          savedVariables = {
	       ShowIcon = 1,
	       ShowLabelText = 1,
          }
     };
     self:RegisterEvent("PLAYER_ENTERING_WORLD");
     self:RegisterEvent("FRIENDLIST_UPDATE");
     self:RegisterEvent("IGNORELIST_UPDATE");
     self:RegisterEvent("VARIABLES_LOADED");
     self:RegisterEvent("PLAYER_REGEN_DISABLED");
     self:RegisterEvent("PLAYER_REGEN_ENABLED");
     --Titan Pals Config
     AceConfig:RegisterOptionsTable("Titan Pals", optionsPals);
     AceConfigDialog:AddToBlizOptions("Titan Pals", LB["TITAN_PALS_CONFIG"], L["TITAN_PANEL"]);
     TitanPanelPals_Init();
end